@@ -9,7 +9,7 @@ import pandas as pd
 
 from accessOutlookEmail import save_attachment, create_account
 
-account = create_account('kreutmair@orcacapital.de', 'ubeRr@schun9')
+account = create_account('kreutmair@orcacapital.de', 'jar54Cet$cosh45')
 
 
 def editSaveMorrison(rename_file: str, load_from_folder: str, save_to_folder: str):
@@ -36,4 +36,9 @@ def editSaveMorrison(rename_file: str, load_from_folder: str, save_to_folder: st
     z_au_leihe.to_excel(rename_file, index=False)
 
 
-editSaveMorrison(r'testFile.xlsx', r'C:\Users\baier\Downloads', r'O:\Listenpflege\AU_Leihe_Option')
+def main():
+    editSaveMorrison(r'testFile.xlsx', r'C:\Users\baier\Downloads', r'O:\Listenpflege\AU_Leihe_Option')
+
+
+if __name__ == '__main__':
+    main()
